@@ -19,11 +19,34 @@
 
 #include <string>
 #include <vector>
+#include <sstream>
+#include <algorithm>
+#include <cctype>
+#include <climits>
 
 
 enum ParsingResult {GOOD, BAD, HELP, VERSION};
 
 
+struct DoublesReader
+{
+    void operator()(const std::string &name, const std::string &value, double &destination);
+};
+
+
+struct IntegerWithSuffixReader
+{
+    void operator()(const std::string &name, const std::string &value, long long &destination);
+    long long parse_int_with_suffix(const std::string &value);
+};
+
+
+struct IntWithSuffixReader
+{
+    void operator()(const std::string &name, const std::string &value, int &destination);
+};
+
+
 class Arguments
 {
 public:
@@ -53,7 +76,7 @@ public:
 
     bool assembly_set;
     std::string assembly;
-    std::vector<std::string> illumina_reads;
+    std::vector<std::string> short_reads;
 
     double length_weight;
     double mean_q_weight;
